Malcolm
=======


|build_status| |coverage| |health| |pypi_version| |readthedocs|

Malcolm is a middlelayer framework that implements high level configure/run
behaviour of control system components like those used in continuous scans. 
This repository contains a Python implementation allowing the creation of 
Malcolm servers and clients. 

Documentation
-------------

Full documentation is available at http://pymalcolm.readthedocs.org

Source Code
-----------

Available from https://github.com/dls-controls/pymalcolm

Installation
------------
To install the latest release, type::

    pip install malcolm

To install the latest code directly from source, type::

    pip install git+git://github.com/dls-controls/pymalcolm.git

Changelog
---------

See `CHANGELOG`_

Contributing
------------

See `CONTRIBUTING`_

License
-------
APACHE License. (see `LICENSE`_)


.. |build_status| image:: https://github.com/dls-controls/pymalcolm/workflows/GitHub%20Actions/badge.svg?branch=master
    :target: https://github.com/dls-controls/pymalcolm/actions
    :alt: Build Status

.. |coverage| image:: https://codecov.io/gh/dls-controls/pymalcolm/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/dls-controls/pymalcolm
    :alt: Test coverage

.. |pypi_version| image:: https://img.shields.io/pypi/v/malcolm.svg
    :target: https://pypi.python.org/pypi/malcolm/
    :alt: Latest PyPI version

.. |readthedocs| image:: https://readthedocs.org/projects/pymalcolm/badge/?version=latest
    :target: http://pymalcolm.readthedocs.org
    :alt: Documentation

.. |health| image:: https://api.codacy.com/project/badge/Grade/9b277852ec9347329f35dc41d068c151
   :target: https://app.codacy.com/app/dls-controls/pymalcolm?utm_source=github.com&utm_medium=referral&utm_content=dls-controls/pymalcolm&utm_campaign=Badge_Grade_Dashboard
   :alt: Code Health

.. _CHANGELOG:
    https://github.com/dls-controls/pymalcolm/blob/master/CHANGELOG.rst

.. _CONTRIBUTING:
    https://github.com/dls-controls/pymalcolm/blob/master/CONTRIBUTING.rst

.. _LICENSE:
    https://github.com/dls-controls/pymalcolm/blob/master/LICENSE
